import { Duration } from "../../core";
/**
 * An object that represents reasons to restart an InitService
 *
 * Pass an instance of this object to the `InitFile`, `InitCommand`,
 * `InitSource` and `InitPackage` objects, and finally to an `InitService`
 * itself to cause the actions (files, commands, sources, and packages)
 * to trigger a restart of the service.
 *
 * For example, the following will run a custom command to install Nginx,
 * and trigger the nginx service to be restarted after the command has run.
 *
 * ```ts
 * const handle = new ec2.InitServiceRestartHandle();
 * ec2.CloudFormationInit.fromElements(
 *   ec2.InitCommand.shellCommand('/usr/bin/custom-nginx-install.sh', { serviceRestartHandles: [handle] }),
 *   ec2.InitService.enable('nginx', { serviceRestartHandle: handle }),
 * );
 * ```
 */
export declare class InitServiceRestartHandle {
    private readonly commands;
    private readonly files;
    private readonly sources;
    private readonly packages;
}
/**
 * Base class for all CloudFormation Init elements
 */
export declare abstract class InitElement {
    /**
     * Returns the init element type for this element.
     */
    abstract readonly elementType: string;
}
/**
 * Options for InitCommand
 */
export interface InitCommandOptions {
    /**
     * Identifier key for this command
     *
     * Commands are executed in lexicographical order of their key names.
     *
     * @default - Automatically generated based on index
     */
    readonly key?: string;
    /**
     * Sets environment variables for the command.
     *
     * This property overwrites, rather than appends, the existing environment.
     *
     * @default - Use current environment
     */
    readonly env?: Record<string, string>;
    /**
     * The working directory
     *
     * @default - Use default working directory
     */
    readonly cwd?: string;
    /**
     * Command to determine whether this command should be run
     *
     * If the test passes (exits with error code of 0), the command is run.
     *
     * @default - Always run the command
     */
    readonly testCmd?: string;
    /**
     * Continue running if this command fails
     *
     * @default false
     */
    readonly ignoreErrors?: boolean;
    /**
     * The duration to wait after a command has finished in case the command causes a reboot.
     *
     * Set this value to `InitCommandWaitDuration.none()` if you do not want to wait for every command;
     * `InitCommandWaitDuration.forever()` directs cfn-init to exit and resume only after the reboot is complete.
     *
     * For Windows systems only.
     *
     * @default - 60 seconds
     */
    readonly waitAfterCompletion?: InitCommandWaitDuration;
    /**
     * Restart the given service(s) after this command has run
     *
     * @default - Do not restart any service
     */
    readonly serviceRestartHandles?: InitServiceRestartHandle[];
}
/**
 * Represents a duration to wait after a command has finished, in case of a reboot (Windows only).
 */
export declare abstract class InitCommandWaitDuration {
    /** Wait for a specified duration after a command. */
    static of(duration: Duration): InitCommandWaitDuration;
    /** Do not wait for this command. */
    static none(): InitCommandWaitDuration;
    /** cfn-init will exit and resume only after a reboot. */
    static forever(): InitCommandWaitDuration;
}
/**
 * Command to execute on the instance
 */
export declare class InitCommand extends InitElement {
    private readonly command;
    private readonly options;
    /**
     * Run a shell command
     *
     * Remember that some characters like `&`, `|`, `;`, `>` etc. have special meaning in a shell and
     * need to be preceded by a `\` if you want to treat them as part of a filename.
     */
    static shellCommand(shellCommand: string, options?: InitCommandOptions): InitCommand;
    /**
     * Run a command from an argv array
     *
     * You do not need to escape space characters or enclose command parameters in quotes.
     */
    static argvCommand(argv: string[], options?: InitCommandOptions): InitCommand;
    readonly elementType: string;
    private constructor();
}
/**
 * Options for an InitService
 */
export interface InitServiceOptions {
    /**
     * Enable or disable this service
     *
     * Set to true to ensure that the service will be started automatically upon boot.
     *
     * Set to false to ensure that the service will not be started automatically upon boot.
     *
     * @default - true if used in `InitService.enable()`, no change to service
     * state if used in `InitService.fromOptions()`.
     */
    readonly enabled?: boolean;
    /**
     * Make sure this service is running or not running after cfn-init finishes.
     *
     * Set to true to ensure that the service is running after cfn-init finishes.
     *
     * Set to false to ensure that the service is not running after cfn-init finishes.
     *
     * @default - same value as `enabled`.
     */
    readonly ensureRunning?: boolean;
    /**
     * Restart service when the actions registered into the restartHandle have been performed
     *
     * Register actions into the restartHandle by passing it to `InitFile`, `InitCommand`,
     * `InitPackage` and `InitSource` objects.
     *
     * @default - No files trigger restart
     */
    readonly serviceRestartHandle?: InitServiceRestartHandle;
}
/**
 * A services that be enabled, disabled or restarted when the instance is launched.
 */
export declare class InitService extends InitElement {
    private readonly serviceName;
    private readonly serviceOptions;
    /**
     * Enable and start the given service, optionally restarting it
     */
    static enable(serviceName: string, options?: InitServiceOptions): InitService;
    /**
     * Disable and stop the given service
     */
    static disable(serviceName: string): InitService;
    readonly elementType: string;
    private constructor();
}
